@@ -23,7 +23,7 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
     list(X=X,w=w)
   }
 
-  
+
   R_prodsum1 <-function(x,l,u,r,r0,r0diff,J,K,Sigma){
     ########################################################################################################
     ## x is vector of dummy variables ( the t_j in gdt paper ), l and u are boundary vectors
@@ -32,8 +32,8 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
        x2 = as.double(x), l2 = as.double(l), u2 = as.double(u),
        r2 = as.double(r), r02 = as.double(r0), r0diff2 = as.double(r0diff),
        J2 = as.integer(J), K2 = as.integer(K), Sigma2 = Sigma,
-       maxpts2 = as.integer(25000), releps2 = as.double(0), 
-       abseps2 = as.double(0.001), tol2 = as.double(0.0001))			
+       maxpts2 = as.integer(25000), releps2 = as.double(0),
+       abseps2 = as.double(0.001), tol2 = as.double(0.0001))
   }
 
   #############################################################################################################
@@ -41,15 +41,15 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   ##  and calculates the difference with the nominal alpha.
   ##  The accuracy of the quadrature integral will depend on the choice of points and weights.
   ##  Here, the number of points in each dimension is an input, N.
-  ##  The midpoint rule is used with a range of -6 to 6 in each dimension. 
+  ##  The midpoint rule is used with a range of -6 to 6 in each dimension.
   #############################################################################################################
 
   typeI <-function(C,alpha,N,r,r0,r0diff,J,K,Sigma,mmp,
                    ushape,lshape,lfix=NULL,ufix=NULL,parallel=parallel,print=print){
-  
+
+    ########################################################################
+    ## the form of the boundary constraints are determined as functions of C.
     ########################################################################
-    ## the form of the boundary constraints are determined as functions of C. 
-    ######################################################################## 
     if(!is.function(ushape)){
       if (ushape=='obf'){
         u<-C*sqrt(r[J]/r)
@@ -59,9 +59,9 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
       }
       else if (ushape=='fixed'){
         u<-c(rep(ufix,J-1),C)
-      } 
+      }
       else if (ushape=='triangular') {
-        u<-C*(1+r/r[J])/sqrt(r) 
+        u<-C*(1+r/r[J])/sqrt(r)
       }
     }else{
       u <- C*ushape(J)
@@ -104,54 +104,54 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   }
   if(print){message("\n",appendLF=FALSE)}
 
-  
+
   ####################################################################################
   ## 'R_prodsum2' evaluates the integrand of Pi_1 according to  gdt paper:
   #####################################################################################
 
-  R_prodsum2 <-function(x,r,r0,l,u,K,delta,delta0,n,sig){
+  R_prodsum2 <-function(x,r,r0, u,K,delta,delta0,n,sig){
     .Call("C_prodsum2",
           x2 = as.double(x), r2 = as.double(r), r02 = as.double(r0),
-          K2 = as.double(K), l2 = as.double(l), u2 = as.double(u),
+          K2 = as.double(K), u2 = as.double(u),
           delta2 = as.double(delta), delta02 = as.double(delta0),
-          n2 = as.double(n), sig2 = as.double(sig))			
+          n2 = as.double(n), sig2 = as.double(sig))
   }
 
 
   ############################################################################################
   ## 'R_prodsum3' evaluates the integrand of Pi_j for j>1.
-  ############################################################################################ 
+  ############################################################################################
 
   R_prodsum3 <-function(x,l,u,r,r0,r0diff,J,K,delta,delta0,
                         n,sig,Sigma,SigmaJ){
     .Call("C_prodsum3",
           x2 = as.double(x), l2 = as.double(l), u2 = as.double(u),
           r2 = as.double(r), r02 = as.double(r0), r0diff2 = as.double(r0diff),
-          Jfull2 = as.integer(J), K2 = as.integer(K), 
+          Jfull2 = as.integer(J), K2 = as.integer(K),
           delta2 = as.double(delta), delta02 = as.double(delta0),
           n2 = as.double(n), sig2 = as.double(sig),
           Sigma2 = Sigma, SigmaJ2 = SigmaJ,
-          maxpts2 = as.integer(25000), releps2 = as.double(0), 
+          maxpts2 = as.integer(25000), releps2 = as.double(0),
           abseps2 = as.double(0.001), tol2 = as.double(0.001))
   }
 
   ######################################################################################################
   ##  'typeII' performs the outer quadrature integrals of Pi_j j=1,...,J  using 'mesh' (stored in mmp_j),
-  ##  'prodsum2' and 'prodsum3' as well as summing the Pi_1,...,Pi_J and calculates the difference 
+  ##  'prodsum2' and 'prodsum3' as well as summing the Pi_1,...,Pi_J and calculates the difference
   ##  with the nominal power.
   ##  The accuracy of the quadrature integral again depends on the choice of points and weights.
   ##  Here, the number of points in each dimension is an input, N.
-  ##  The midpoint rule is used with a range of -6 to 6 in each dimension. 
+  ##  The midpoint rule is used with a range of -6 to 6 in each dimension.
   ########################################################################################################
 
   typeII <-function(n,beta,l,u,N,r,r0,r0diff,J,K,delta,delta0,sig,Sigma,mmp_j,parallel=parallel){
-  
+
     evs <- apply(mmp_j[[1]]$X,1,R_prodsum2,
-                 r=r,r0=r0,K=K,l=l,u=u,delta=delta,delta0=delta0,n=n,sig=sig)
+                 r=r,r0=r0,K=K,u=u,delta=delta,delta0=delta0,n=n,sig=sig)
     pi<-mmp_j[[1]]$w%*%evs
 
     if(J>1){
-      for (j in 2:J){  
+      for (j in 2:J){
         A<-diag(sqrt(r[j]/(r[j]-r[1:(j-1)])),ncol=j-1)
         SigmaJ<-A%*%(Sigma[1:(j-1),1:(j-1)]-Sigma[1:(j-1),j]%*%t(Sigma[1:(j-1),j]))%*%A
         if(parallel){
@@ -178,11 +178,11 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   if(alpha<0 | alpha>1 | power<0 | power>1){stop("Error rate or power not between 0 and 1.")}
   if(length(r)!=length(r0)){stop("Different length of allocation ratios on control and experimental treatments.")}
   if(length(r)!=J){stop("Length of allocation ratios does not match number of stages.")}
-  
+
   if(is.numeric(p) & is.numeric(p0) & is.numeric(delta) & is.numeric(delta0) & is.numeric(sd)){
     stop("Specify the effect sizes either via (p, p0) or via (delta, delta0, sd) and set the other parameters to NULL.")
   }
-  
+
   if(is.numeric(p) & is.numeric(p0)){
     if(p<0 | p>1 | p0<0 | p0>1){stop("Treatment effect parameter not within 0 and 1.")}
     if(p<=p0){stop("Interesting treatment effect must be larger than uninteresting effect.")}
@@ -194,7 +194,7 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
       stop("Specify the effect sizes either via (p, p0) or via (delta, delta0, sd).")
     }
   }
-  
+
   if(is.function(ushape) & is.function(lshape)){
     warning("You have specified your own functions for both the lower and upper boundary. Please check carefully whether the resulting boundaries are sensible.")
   }
@@ -213,11 +213,11 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
     b <- lshape(J)
     if(!all(sort(b,decreasing=FALSE)==b)){stop("Lower boundary shape is decreasing.")}
   }
- 
+
   ############################################################################
   ## Convert treatment effects into absolute effects with standard deviation 1:
   ############################################################################
-  
+
   if(is.numeric(p) & is.numeric(p0)){
     delta <- sqrt(2) * qnorm(p)
     delta0 <- sqrt(2) * qnorm(p0)
@@ -230,19 +230,19 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   }
 
   ############################################################################
-  ## gaussian quadrature's grid and weights for stages 1:J 
+  ## gaussian quadrature's grid and weights for stages 1:J
   ############################################################################
- 
+
   mmp_j = as.list(rep(NA,J))
   for(j in 1:J){
       mmp_j[[j]] = mesh(x=(1:N-.5)/N*12-6,j,w=rep(12/N,N))
   }
-  
-  
+
+
   ############################################################################
   ## Ensure equivalent allocation ratios yield same sample size
   ############################################################################
-  
+
   h <- min(c(r,r0))
   r <- r/h
   r0 <- r0/h
@@ -254,7 +254,7 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   bottom<-matrix(r,J,J)
   top<-matrix(rep(r,rep(J,J)),J,J)
   top[upper.tri(top)]<-t(top)[upper.tri(top)]
-  bottom[upper.tri(bottom)]<-t(bottom)[upper.tri(bottom)] 
+  bottom[upper.tri(bottom)]<-t(bottom)[upper.tri(bottom)]
   Sigma<-sqrt(top/bottom)
 
   ###############################################################################
@@ -262,7 +262,7 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   ###############################################################################
 
   r0lag1<-c(0,r0[1:J-1])
-  r0diff<-r0-r0lag1 
+  r0diff<-r0-r0lag1
 
 
   ################################
@@ -272,14 +272,14 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   if(print){
      message("   i) find lower and upper boundaries\n      ",appendLF=FALSE)
   }
-  
-  # Quick & dirty fix to enable single-stage design with specification lshape="obf" 
+
+  # Quick & dirty fix to enable single-stage design with specification lshape="obf"
   if(!is.function(lshape)){
     if(J==1 & lshape=="obf"){
       lshape <- "pocock"
     }
   }
-  
+
   uJ<-NULL
   ## making sure that lfix is not larger then uJ
   try(uJ<-uniroot(typeI,c(qnorm(1-alpha)/2,5),alpha=alpha,N=N,r=r,r0=r0,r0diff=r0diff,
@@ -299,7 +299,7 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
     else if (ushape=='fixed'){
       u<-c(rep(ufix,J-1),uJ)
     } else if (ushape=='triangular') {
-      u<-uJ*(1+r/r[J])/sqrt(r) 
+      u<-uJ*(1+r/r[J])/sqrt(r)
     }
   }else{
     u <- uJ*ushape(J)
@@ -328,25 +328,25 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   #########################################################
   ## Find alpha.star
   #########################################################
-  
+
   if(print){
      message("\n  ii) define alpha star\n",appendLF=FALSE)
   }
-  
+
   alpha.star <- numeric(J)
   alpha.star[1] <- typeI(u[1],
-                   alpha = 0, N = N, r = r[1], r0 = r0[1],r0diff = r0diff[1], 
-                   J = 1, K = K, Sigma = Sigma, mmp = mmp_j[[1]],                   
-                   ushape = "fixed",lshape = "fixed",lfix = NULL, ufix = NULL, 
-                   parallel = parallel, print = FALSE 
-                   )  
+                   alpha = 0, N = N, r = r[1], r0 = r0[1],r0diff = r0diff[1],
+                   J = 1, K = K, Sigma = Sigma, mmp = mmp_j[[1]],
+                   ushape = "fixed",lshape = "fixed",lfix = NULL, ufix = NULL,
+                   parallel = parallel, print = FALSE
+                   )
   if (J > 1){
       for (j in 2:J){
           alpha.star[j] <- typeI(u[j],
-                           alpha = 0, N = N, r = r[1:j], r0 = r0[1:j],r0diff = r0diff[1:j], 
-                           J = j, K = K, Sigma = Sigma, mmp = mmp_j[[j]],  
+                           alpha = 0, N = N, r = r[1:j], r0 = r0[1:j],r0diff = r0diff[1:j],
+                           J = j, K = K, Sigma = Sigma, mmp = mmp_j[[j]],
                            ushape = "fixed",lshape = "fixed",lfix = l[1:(j - 1)],ufix = u[1:(j - 1)],
-                           parallel = parallel, print = FALSE  
+                           parallel = parallel, print = FALSE
                            )
       }
   }
@@ -373,13 +373,13 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
 
   }else{
 
-    n <- nstart 
+    n <- nstart
     ###################################################################################################
     ## program could be very slow starting at n=0, may want to start at more sensible lower bound on n
     ## unlike type I error, power equation does not neccessarily have unique solution n therefore search
     ## for smallest solution:
     ####################################################################################################
-    
+
     pow <- 0
     if(sample.size){
       if(print){
@@ -399,10 +399,10 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
       }
       if(print){
          message(paste0("      (maximum iteration number = ",nstop-nstart+1,")\n      "),appendLF=FALSE)
-      }      
+      }
       while (pow==0 & n<=nstop){
         n <- n + 1
-        pow <- (typeII(n, beta=1 - power, l=l, u=u, N=N, r=r, r0=r0, r0diff=r0diff, J=J, 
+        pow <- (typeII(n, beta=1 - power, l=l, u=u, N=N, r=r, r0=r0, r0diff=r0diff, J=J,
                       K=K, delta=delta, delta0=delta0, sig=sig, Sigma=Sigma, mmp_j = mmp_j,
                       parallel = parallel
                       ) < 0)
@@ -414,14 +414,14 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
          message("\n",appendLF=FALSE)
       }
       if((n - 1)==nstop){warning("The sample size search was stopped because the maximum sample size (nstop, default: 3 times the sample size of a fixed sample design) was reached.\n")}
-      
+
     }else{
       n <- NULL
     }
   }
 
   res <- NULL
-  res$l <- l  
+  res$l <- l
   res$u <- u
   res$n <- n
 
@@ -437,7 +437,7 @@ mams <- function(K=4, J=2, alpha=0.05, power=0.9, r=1:2, r0=1:2, p=0.75, p0=0.5,
   }else{
     res$power <- NA
   }
-  
+
   res$type <- type
 
   class(res)<-"MAMS"
