@@ -10,13 +10,13 @@
 /* .Call calls */
 extern SEXP C_prodsum1(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP C_prodsum1_nb(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP C_prodsum2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP C_prodsum2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP C_prodsum3(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"C_prodsum1",    (DL_FUNC) &C_prodsum1,    13},
     {"C_prodsum1_nb", (DL_FUNC) &C_prodsum1_nb, 13},
-    {"C_prodsum2",    (DL_FUNC) &C_prodsum2,    10},
+    {"C_prodsum2",    (DL_FUNC) &C_prodsum2,    9},
     {"C_prodsum3",    (DL_FUNC) &C_prodsum3,    18},
     {NULL, NULL, 0}
 };
